=======
cGADDAG
=======

An implementation of a GADDAG_ in C.

A GADDAG data structure provides rapid word lookups for prefixes, suffixes and substrings, making it ideal for use in applications such as Scrabble_ move generation.

cGADDAG currently only supports the ASCII alphabet.

Usage
-----

For an example how to use cGADDAG, see example.c_.

License
-------

Licensed under the MIT License, see LICENSE_.

.. _GADDAG: https://en.wikipedia.org/wiki/GADDAG
.. _Scrabble: https://en.wikipedia.org/wiki/Scrabble
.. _LICENSE: https://github.com/jorbas/cGADDAG/blob/master/LICENSE
.. _example.c: https://github.com/jorbas/cGADDAG/blob/master/src/example.c

